==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QReadWriteLock_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qreadwritelock.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QReadWriteLock(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QReadWriteLock")
    QReadWriteLock *_ptr = reinterpret_cast<QReadWriteLock *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QReadWriteLock(QReadWriteLock::RecursionMode)
void __qt_construct_QReadWriteLock_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QReadWriteLock(QReadWriteLock::RecursionMode)")
    Q_UNUSED(__java_arguments)
    QReadWriteLock *__qt_this = new(__qtjambi_ptr) QReadWriteLock();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QReadWriteLock(QReadWriteLock::RecursionMode)
void __qt_construct_QReadWriteLock_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QReadWriteLock(QReadWriteLock::RecursionMode)")
    jobject recursionMode0 = __java_arguments[0].l;
    QReadWriteLock::RecursionMode __qt_recursionMode0 = qtjambi_cast<QReadWriteLock::RecursionMode>(__jni_env, recursionMode0);
    QReadWriteLock *__qt_this = new(__qtjambi_ptr) QReadWriteLock(QReadWriteLock::RecursionMode(__qt_recursionMode0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QReadWriteLock
void __qt_destruct_QReadWriteLock(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QReadWriteLock")
    reinterpret_cast<QReadWriteLock*>(ptr)->~QReadWriteLock();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_initialize_1native__Lio_qt_core_QReadWriteLock_2Lio_qt_core_QReadWriteLock_00024RecursionMode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject recursionMode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = recursionMode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QReadWriteLock_1, sizeof(QReadWriteLock), typeid(QReadWriteLock), false, &deleter_QReadWriteLock, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QReadWriteLock::lockForRead()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_lockForRead_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::lockForRead()", __qt_this)
        __qt_this->lockForRead();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QReadWriteLock::lockForWrite()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_lockForWrite_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::lockForWrite()", __qt_this)
        __qt_this->lockForWrite();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QReadWriteLock::tryLockForRead()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForRead_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForRead()", __qt_this)
        __java_return_value = __qt_this->tryLockForRead();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForRead(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForRead_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForRead(int)", __qt_this)
        __java_return_value = __qt_this->tryLockForRead(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForWrite()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForWrite_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForWrite()", __qt_this)
        __java_return_value = __qt_this->tryLockForWrite();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForWrite(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForWrite_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForWrite(int)", __qt_this)
        __java_return_value = __qt_this->tryLockForWrite(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::unlock()", __qt_this)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QReadWriteLock(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QReadWriteLock>("QReadWriteLock", "io/qt/core/QReadWriteLock");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QReadWriteLock, {
        ConstructorInfo(&__qt_construct_QReadWriteLock_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QReadWriteLock_1, "Lio/qt/core/QReadWriteLock$RecursionMode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QReadWriteLock);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QReadWriteLock::RecursionMode>("QReadWriteLock::RecursionMode", "io/qt/core/QReadWriteLock$RecursionMode");
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QReadWriteLock_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qreadwritelock.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QReadWriteLock(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QReadWriteLock")
    QReadWriteLock *_ptr = reinterpret_cast<QReadWriteLock *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QReadWriteLock(QReadWriteLock::RecursionMode)
void __qt_construct_QReadWriteLock(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QReadWriteLock(QReadWriteLock::RecursionMode)")
    Q_UNUSED(__java_arguments)
    QReadWriteLock *__qt_this = new(__qtjambi_ptr) QReadWriteLock();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// new QReadWriteLock(QReadWriteLock::RecursionMode)
void __qt_construct_QReadWriteLock_QReadWriteLock_RecursionMode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QReadWriteLock(QReadWriteLock::RecursionMode)")
    jobject recursionMode0 = __java_arguments[0].l;
    QReadWriteLock::RecursionMode __qt_recursionMode0 = qtjambi_cast<QReadWriteLock::RecursionMode>(__jni_env, recursionMode0);
    QReadWriteLock *__qt_this = new(__qtjambi_ptr) QReadWriteLock(QReadWriteLock::RecursionMode(__qt_recursionMode0));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_initialize_1native__Lio_qt_core_QReadWriteLock_2Lio_qt_core_QReadWriteLock_00024RecursionMode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject recursionMode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QReadWriteLock::QReadWriteLock(QReadWriteLock::RecursionMode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = recursionMode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QReadWriteLock_QReadWriteLock_RecursionMode, sizeof(QReadWriteLock), typeid(QReadWriteLock), 0, false, &deleter_QReadWriteLock, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QReadWriteLock
void __qt_destruct_QReadWriteLock(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QReadWriteLock")
    reinterpret_cast<QReadWriteLock*>(ptr)->~QReadWriteLock();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QReadWriteLock::lockForRead()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_lockForRead_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::lockForRead()", __this_nativeId)
        __qt_this->lockForRead();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QReadWriteLock::lockForWrite()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_lockForWrite_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::lockForWrite()", __this_nativeId)
        __qt_this->lockForWrite();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QReadWriteLock::tryLockForRead()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForRead_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForRead()", __this_nativeId)
        __java_return_value = __qt_this->tryLockForRead();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForRead(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForRead_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForRead(int)", __this_nativeId)
        __java_return_value = __qt_this->tryLockForRead(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForWrite()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForWrite_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForWrite()", __this_nativeId)
        __java_return_value = __qt_this->tryLockForWrite();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::tryLockForWrite(int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_tryLockForWrite_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timeout0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::tryLockForWrite(int)", __this_nativeId)
        __java_return_value = __qt_this->tryLockForWrite(static_cast<int>(timeout0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QReadWriteLock::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QReadWriteLock_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QReadWriteLock *__qt_this = QtJambiAPI::objectFromNativeId<QReadWriteLock>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QReadWriteLock::unlock()", __this_nativeId)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QReadWriteLock(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QReadWriteLock>("QReadWriteLock", "io/qt/core/QReadWriteLock");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QReadWriteLock, {
        ConstructorInfo(&__qt_construct_QReadWriteLock, nullptr)
       ,ConstructorInfo(&__qt_construct_QReadWriteLock_QReadWriteLock_RecursionMode, "Lio/qt/core/QReadWriteLock$RecursionMode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QReadWriteLock);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QReadWriteLock::RecursionMode>("QReadWriteLock::RecursionMode", "io/qt/core/QReadWriteLock$RecursionMode");
// END: enums and flags
}
